@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 __all__ = ['ANY_ARGUMENT',
            'ANY_ARGUMENTS',
@@ -47,14 +47,14 @@ from fluentmock.exceptions import (CouldNotVerifyCallError,
                                    InvalidUseOfAnyArgumentsError,
                                    NoCallsStoredError,
                                    HasBeenCalledWithUnexpectedArgumentsError)
-from fluentmock.matchers import FluentMatcher, FluentAnyArguments, FluentAnyArgument
+from fluentmock.matchers import FluentMatcher, FluentAnyArguments, FluentAnyArgument, NeverMatcher
 
 LOGGER = getLogger(__name__)
 
 ANY_ARGUMENT = FluentAnyArgument()
 ANY_ARGUMENTS = FluentAnyArguments()
 AT_LEAST_ONCE = 'AT-LEAST-ONCE'
-NEVER = 'NEVER'
+NEVER = NeverMatcher()
 
 _configurators = {}
 _patch_entries = []
@@ -285,12 +285,14 @@ class Verifier(FluentTarget):
 
     def __init__(self, target, times):
         FluentTarget.__init__(self, target)
-        self._times = times
 
         if times not in [NEVER, AT_LEAST_ONCE]:
-            error_message = 'Argument times can be "{never}" or "{once}".'.format(never=NEVER, once=AT_LEAST_ONCE)
+            error_message = 'Argument times can be "{never}" or "{once}".'.format(never=NEVER.__class__.__name__,
+                                                                                  once=AT_LEAST_ONCE)
             raise ValueError(error_message)
 
+        self._times = times
+
     def __getattr__(self, attribute_name):
         self.attribute_name = attribute_name
 
@@ -299,66 +301,67 @@ class Verifier(FluentTarget):
 
         return self
 
-    def __call__(self, *arguments, **keyword_arguments):
+    def _ensure_no_matchers_in_arguments(self, arguments, keyword_arguments):
+        call_entry = call(*arguments, **keyword_arguments)
+        call_entry_string = str(call_entry).replace('call', self.full_qualified_target_name)
+
+        for argument in arguments:
+            if isinstance(argument, FluentMatcher):
+                raise FoundMatcherInNativeVerificationError(call_entry_string)
+        for key in keyword_arguments:
+            if isinstance(keyword_arguments[key], FluentMatcher):
+                raise FoundMatcherInNativeVerificationError(call_entry_string)
+
+    def _count_matching_call_entries(self, arguments, keyword_arguments):
+        matching_call_entries = 0
         method_of_mock = getattr(self.object, self.attribute_name)
+
         if isinstance(self.object, Mock) and isinstance(method_of_mock, Mock):
+            self._ensure_no_matchers_in_arguments(arguments, keyword_arguments)
+
             call_entry = call(*arguments, **keyword_arguments)
-            call_entry_string = str(call_entry).replace('call', self.full_qualified_target_name)
-
-            for argument in arguments:
-                if isinstance(argument, FluentMatcher):
-                    raise FoundMatcherInNativeVerificationError(call_entry_string)
-
-            for key in keyword_arguments:
-                if isinstance(keyword_arguments[key], FluentMatcher):
-                    raise FoundMatcherInNativeVerificationError(call_entry_string)
-
-            if self._times == NEVER:
-                if call_entry in method_of_mock.call_args_list:
-                    raise HasBeenCalledAtLeastOnceError(call_entry_string)
-            else:
-                method_of_mock.assert_called_with(*arguments, **keyword_arguments)
+            matching_call_entries = method_of_mock.call_args_list.count(call_entry)
         else:
-            if self._times == NEVER:
-                self._assert_never_called(*arguments, **keyword_arguments)
-            else:
-                self._assert_called(*arguments, **keyword_arguments)
+            for call_entry in _call_entries:
+                if call_entry.matches(self.object, self.attribute_name, arguments, keyword_arguments):
+                    matching_call_entries += 1
+        return matching_call_entries
 
-    def _assert_never_called(self, *arguments, **keyword_arguments):
-        for call_entry in _call_entries:
-            if call_entry.matches(self.object, self.attribute_name, arguments, keyword_arguments):
-                raise HasBeenCalledAtLeastOnceError(call_entry)
+    def __call__(self, *arguments, **keyword_arguments):
+        matching_call_entries = self._count_matching_call_entries(arguments, keyword_arguments)
 
-    def _assert_called(self, *arguments, **keyword_arguments):
-        expected_call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
+        if self._times is NEVER and not NEVER.matches(matching_call_entries):
+            expected_call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
+            raise HasBeenCalledAtLeastOnceError(expected_call_entry)
 
-        if not _call_entries:
-            raise NoCallsStoredError(expected_call_entry)
+        if self._times == AT_LEAST_ONCE:
+            if matching_call_entries == 0:
+                method_of_mock = getattr(self.object, self.attribute_name)
+                if isinstance(self.object, Mock) and isinstance(method_of_mock, Mock):
+                    self._ensure_no_matchers_in_arguments(arguments, keyword_arguments)
 
-        for call_entry in _call_entries:
-            if call_entry.matches(self.object, self.attribute_name, arguments, keyword_arguments):
-                return
+                    method_of_mock.assert_called_with(*arguments, **keyword_arguments)
+                else:
+                    expected_call_entry = FluentCallEntry(self.object, self.attribute_name,
+                                                          arguments, keyword_arguments)
+                    if not _call_entries:
+                        raise NoCallsStoredError(expected_call_entry)
 
-        found_calls = self._find_calls_to_same_target()
+                    found_calls = []
 
-        if found_calls:
-            if arguments and ANY_ARGUMENTS in arguments:
-                if len(arguments) > 1:
-                    raise InvalidUseOfAnyArgumentsError()
-                return
-            raise HasBeenCalledWithUnexpectedArgumentsError(expected_call_entry, found_calls)
+                    for call_entry in _call_entries:
+                        target = call_entry.target
+                        if target.is_equal_to(self.object, self.attribute_name):
+                            found_calls.append(call_entry)
 
-        raise CouldNotVerifyCallError(expected_call_entry)
+                    if found_calls:
+                        if arguments and ANY_ARGUMENTS in arguments:
+                            if len(arguments) > 1:
+                                raise InvalidUseOfAnyArgumentsError()
+                            return
+                        raise HasBeenCalledWithUnexpectedArgumentsError(expected_call_entry, found_calls)
 
-    def _find_calls_to_same_target(self):
-        found_calls = []
-
-        for call_entry in _call_entries:
-            target = call_entry.target
-            if target.is_equal_to(self.object, self.attribute_name):
-                found_calls.append(call_entry)
-
-        return found_calls
+                    raise CouldNotVerifyCallError(expected_call_entry)
 
 
 def create_mock(*arguments, **keyword_arguments):
